unit CMclk_W2;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  CMDispl, ExtCtrls, StdCtrls, ComCtrls, Buttons;

type
  TFormClock = class(TForm)
    Timer1: TTimer;
    CheckBoxTimeFormat24h: TCheckBox;
    RadioGroupStyle: TRadioGroup;
    Label1: TLabel;
    TrackBarSegmentSize: TTrackBar;
    ColorDialog1: TColorDialog;
    ButtonColorBackground: TButton;
    ButtonColorOn: TButton;
    ButtonColorOff: TButton;
    Bevel1: TBevel;
    Label2: TLabel;
    BitBtnClose: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure CheckBoxTimeFormat24hClick(Sender: TObject);
    procedure RadioGroupStyleClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure TrackBarSegmentSizeChange(Sender: TObject);
    procedure ButtonColorBackgroundClick(Sender: TObject);
    procedure ButtonColorOnClick(Sender: TObject);
    procedure ButtonColorOffClick(Sender: TObject);
    procedure BitBtnCloseClick(Sender: TObject);
  private
    { Private-Deklarationen }
    CMDisplayClock: TCMDisplay;
    TimeFormat: string;
  public
    { Public-Deklarationen }
  end;

const
  TimeFormat12h = 'hh:mm:ss a/p';
  TimeFormat24h = 'hh:mm:ss';

var
  FormClock: TFormClock;

implementation

{$R *.DFM}

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.FormCreate(Sender: TObject);
begin

  { dynamic creation: compiling before installation is possible! }
  CMDisplayClock := TCMDisplay.Create (Self);
  with CMDisplayClock do begin
    Parent := Self;
    DigitCount := 10;
    DisplayStyle := ds5x7Square;
    SegmentThick := 8;
    Top := 15;
    Left := 10;
    Width := 500;
  end;

  { Default: US time format }
  TimeFormat :=  TimeFormat12h;

end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.FormDestroy(Sender: TObject);
begin
  CMDisplayClock.Free;
end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.Timer1Timer(Sender: TObject);
begin
  if CMDisplayClock <> nil then
    CMDisplayClock.Caption := FormatDateTime (TimeFormat, Now)
end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.CheckBoxTimeFormat24hClick(Sender: TObject);
begin
  if CheckBoxTimeFormat24h.Checked then
    TimeFormat :=  TimeFormat24h
  else
    TimeFormat :=  TimeFormat12h;
end;

{**********************************************************************}
{ switch between 3 styles                                              }
{**********************************************************************}

procedure TFormClock.RadioGroupStyleClick(Sender: TObject);
begin
  CMDisplayClock.DisplayStyle := TDisplayStyle (RadioGroupStyle.ItemIndex);
end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.TrackBarSegmentSizeChange(Sender: TObject);
begin
  CMDisplayClock.SegmentThick := TrackBarSegmentSize.Position;
end;

{**********************************************************************}
{ select color of background                                           }
{**********************************************************************}

procedure TFormClock.ButtonColorBackgroundClick(Sender: TObject);
begin
  if ColorDialog1.Execute then
    CMDisplayClock.ColorBack := ColorDialog1.Color;
end;

{**********************************************************************}
{ select color of lit segment                                          }
{**********************************************************************}

procedure TFormClock.ButtonColorOnClick(Sender: TObject);
begin
  if ColorDialog1.Execute then
    CMDisplayClock.ColorOn := ColorDialog1.Color;
end;

{**********************************************************************}
{ select color of dark segment                                         }
{**********************************************************************}

procedure TFormClock.ButtonColorOffClick(Sender: TObject);
begin
  if ColorDialog1.Execute then
    CMDisplayClock.ColorOff := ColorDialog1.Color;
end;

{**********************************************************************}
{                                                                      }
{**********************************************************************}

procedure TFormClock.BitBtnCloseClick(Sender: TObject);
begin
  close;
end;

end.
